@@ -138,7 +138,7 @@ class Screen(object):
         if self.exists:
             infos = getoutput("screen -ls | grep %s" % self.name).split('\t')[1:]
             self._id = infos[0].split('.')[0]
-            if len(infos==3):
+            if len(infos)==3:
                 self._date = infos[1][1:-1]
                 self._status = infos[2][1:-1]
             else:
